@@ -23,8 +23,9 @@
 
 #include <stdlib.h>
 
-#include "glib.h"
+#include "gunicode.h"
 #include "gunidecomp.h"
+#include "gmem.h"
 #include "gunicomp.h"
 #include "gunicodeprivate.h"
 
